==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/en_GB.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Documents",
"Can't create document" => "Can't create document",
"You don't have permission to rename this document" => "You don't have permission to rename this document",
"Directory saved successfully." => "Directory saved successfully.",
"An error occurred while changing directory." => "An error occurred whilst changing directory.",
"Saved" => "Saved",
"Format filter server is down or misconfigured" => "Format filter server is down or misconfigured",
"Conversion failed. Check log for details." => "Conversion failed. Check log for details.",
"Saving..." => "Saving...",
"Failed to load documents." => "Failed to load documents.",
"No documents were found. Upload or create a document to get started!" => "No documents were found. Upload or create a document to get started!",
"No connection to server. Trying to reconnect." => "No connection to server. Trying to reconnect.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Failed to load this document. Please check if it can be opened with an external ODT editor. This might also mean it has been unshared or deleted recently.",
"Save" => "Save",
"Loading documents..." => "Loading documents...",
"'.' is an invalid file name." => "'.' is an invalid file name.",
"File name cannot be empty." => "File name cannot be empty.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Invalid name: '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed.",
"Align Left" => "Align Left",
"Alignment" => "Alignment",
"Align Right" => "Align Right",
"Annotate" => "Annotate",
"Background" => "Background",
"Bold" => "Bold",
"Bottom" => "Bottom",
"Cancel" => "Cancel",
"Center" => "Centre",
"Clone" => "Clone",
"Clone this Style" => "Clone this Style",
"Close" => "Close",
"Color" => "Colour",
"Create" => "Create",
"Decrease Indent" => "Decrease Indent",
"Default Style" => "Default Style",
"Delete" => "Delete",
"Family" => "Family",
"Font" => "Font",
"Font Effects" => "Font Effects",
"Format" => "Format",
"Increase Indent" => "Increase Indent",
"Insert Image" => "Insert Image",
"Invite Members" => "Invite Members",
"Italic" => "Italic",
"Justified" => "Justified",
"Justify" => "Justify",
"Left" => "Left",
"Loading" => "Loading",
"Members" => "Members",
"New Name:" => "New Name:",
"OK" => "OK",
"Open" => "Open",
"Options" => "Options",
"Paragraph..." => "Paragraph...",
"Paragraph Styles" => "Paragraph Styles",
"Redo" => "Redo",
"Right" => "Right",
"Size" => "Size",
"Spacing" => "Spacing",
"Strikethrough" => "Strikethrough",
"Style" => "Style",
"Text" => "Text",
"Top" => "Top",
"Underline" => "Underline",
"Undo" => "Undo",
"Unknown Author" => "Unknown Author",
"Edit" => "Edit",
"Share" => "Share",
"guest" => "guest",
"MS Word support (requires openOffice/libreOffice)" => "MS Word support (requires openOffice/libreOffice)",
"Local" => "Local",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php",
"External" => "External",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice is installed on external server running a format filter server",
"Disabled" => "Disabled",
"No MS Word support" => "No MS Word support",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "Server URL",
"Apply and test" => "Apply and test",
"New document" => "New document",
"Upload (max. %s)" => "Upload (max. %s)",
"Upload" => "Upload",
"Save new documents to" => "Save new documents to",
"Wrong password. Please retry." => "Incorrect password. Please try again.",
"Password" => "Password",
"Guest %s" => "Guest %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "This link has expired or is incorrect. Please contact the person who shared it with you for details.",
"Advanced feature-set" => "Advanced feature-set",
"(Unstable)" => "(Unstable)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/en_GB.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Documents",
"Can't create document" => "Can't create document",
"You don't have permission to rename this document" => "You don't have permission to rename this document",
"File does not exist" => "File does not exist",
"Directory saved successfully." => "Directory saved successfully.",
"An error occurred while changing directory." => "An error occurred whilst changing directory.",
"Saved" => "Saved",
"Format filter server is down or misconfigured" => "Format filter server is down or misconfigured",
"Conversion failed. Check log for details." => "Conversion failed. Check log for details.",
"Saving..." => "Saving...",
"Failed to load documents." => "Failed to load documents.",
"No documents were found. Upload or create a document to get started!" => "No documents were found. Upload or create a document to get started!",
"No connection to server. Trying to reconnect." => "No connection to server. Trying to reconnect.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Failed to load this document. Please check if it can be opened with an external ODT editor. This might also mean it has been unshared or deleted recently.",
"Save" => "Save",
"Loading documents..." => "Loading documents...",
"'.' is an invalid file name." => "'.' is an invalid file name.",
"File name cannot be empty." => "File name cannot be empty.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Invalid name: '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed.",
"Align Left" => "Align Left",
"Alignment" => "Alignment",
"Align Right" => "Align Right",
"Annotate" => "Annotate",
"Background" => "Background",
"Bold" => "Bold",
"Bottom" => "Bottom",
"Cancel" => "Cancel",
"Center" => "Centre",
"Clone" => "Clone",
"Clone this Style" => "Clone this Style",
"Close" => "Close",
"Color" => "Colour",
"Create" => "Create",
"Decrease Indent" => "Decrease Indent",
"Default Style" => "Default Style",
"Delete" => "Delete",
"Family" => "Family",
"Font" => "Font",
"Font Effects" => "Font Effects",
"Format" => "Format",
"Increase Indent" => "Increase Indent",
"Insert Image" => "Insert Image",
"Invite Members" => "Invite Members",
"Italic" => "Italic",
"Justified" => "Justified",
"Justify" => "Justify",
"Left" => "Left",
"Loading" => "Loading",
"Members" => "Members",
"New Name:" => "New Name:",
"OK" => "OK",
"Open" => "Open",
"Options" => "Options",
"Paragraph..." => "Paragraph...",
"Paragraph Styles" => "Paragraph Styles",
"Redo" => "Redo",
"Right" => "Right",
"Size" => "Size",
"Spacing" => "Spacing",
"Strikethrough" => "Strikethrough",
"Style" => "Style",
"Text" => "Text",
"Top" => "Top",
"Underline" => "Underline",
"Undo" => "Undo",
"Unknown Author" => "Unknown Author",
"Shared" => "Shared",
"Error" => "Error",
"Error while sharing" => "Error whilst sharing",
"Error while unsharing" => "Error whilst unsharing",
"Error while changing permissions" => "Error whilst changing permissions",
"Shared with you and the group {group} by {owner}" => "Shared with you and the group {group} by {owner}",
"Shared with you by {owner}" => "Shared with you by {owner}",
"Share with users or groups …" => "Share with users or groups …",
"Share with users, groups or remote users …" => "Share with users, groups or remote users …",
"Share" => "Share",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Share with people on other ownClouds using the syntax username@example.com/owncloud",
"Share link" => "Share link",
"The public link will expire no later than {days} days after it is created" => "The public link will expire no later than {days} days after it is created",
"Link" => "Link",
"Password protect" => "Password protect",
"Password" => "Password",
"Choose a password for the public link" => "Choose a password for the public link",
"Allow editing" => "Allow editing",
"Email link to person" => "Email link to person",
"Send" => "Send",
"Set expiration date" => "Set expiration date",
"Expiration" => "Expiration",
"Expiration date" => "Expiration date",
"An error occured. Please try again" => "An error occured. Please try again",
"Adding user..." => "Adding user...",
"group" => "group",
"remote" => "remote",
"Resharing is not allowed" => "Resharing is not allowed",
"Shared in {item} with {user}" => "Shared in {item} with {user}",
"Unshare" => "Unshare",
"notify by email" => "notify by email",
"can share" => "can share",
"can edit" => "can edit",
"access control" => "access control",
"create" => "create",
"change" => "change",
"delete" => "delete",
"Password protected" => "Password protected",
"Error unsetting expiration date" => "Error unsetting expiration date",
"Error setting expiration date" => "Error setting expiration date",
"Sending ..." => "Sending ...",
"Email sent" => "Email sent",
"Warning" => "Warning",
"Edit" => "Edit",
"guest" => "guest",
"MS Word support (requires openOffice/libreOffice)" => "MS Word support (requires openOffice/libreOffice)",
"Local" => "Local",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php",
"External" => "External",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice is installed on external server running a format filter server",
"Disabled" => "Disabled",
"No MS Word support" => "No MS Word support",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "Server URL",
"Apply and test" => "Apply and test",
"New document" => "New document",
"Upload (max. %s)" => "Upload (max. %s)",
"Upload" => "Upload",
"Save new documents to" => "Save new documents to",
"Wrong password. Please retry." => "Incorrect password. Please try again.",
"Guest %s" => "Guest %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "This link has expired or is incorrect. Please contact the person who shared it with you for details.",
"Advanced feature-set" => "Advanced feature-set",
"(Unstable)" => "(Unstable)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
